# coding: utf-8

"""
    Identity Security Cloud V2024 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2024
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v2024.models.account_activity import AccountActivity

class TestAccountActivity(unittest.TestCase):
    """AccountActivity unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AccountActivity:
        """Test AccountActivity
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AccountActivity`
        """
        model = AccountActivity()
        if include_optional:
            return AccountActivity(
                id = '2c9180835d2e5168015d32f890ca1581',
                name = '2c9180835d2e5168015d32f890ca1581',
                created = '2017-07-11T18:45:37.098Z',
                modified = '2018-06-25T20:22:28.104Z',
                completed = '2018-10-19T13:49:37.385Z',
                completion_status = 'SUCCESS',
                type = 'appRequest',
                requester_identity_summary = sailpoint.v2024.models.identity_summary.IdentitySummary(
                    id = 'ff80818155fe8c080155fe8d925b0316', 
                    name = 'SailPoint Services', 
                    identity_id = 'c15b9f5cca5a4e9599eaa0e64fa921bd', 
                    completed = True, ),
                target_identity_summary = sailpoint.v2024.models.identity_summary.IdentitySummary(
                    id = 'ff80818155fe8c080155fe8d925b0316', 
                    name = 'SailPoint Services', 
                    identity_id = 'c15b9f5cca5a4e9599eaa0e64fa921bd', 
                    completed = True, ),
                errors = [sailpoint.connector.ConnectorException: java.lang.InterruptedException: Timeout waiting for response to message 0 from client 57a4ab97-ab3f-4aef-9fe2-0eaf15c73d26 after 60 seconds.],
                warnings = [Some warning, another warning],
                items = [
                    sailpoint.v2024.models.account_activity_item.AccountActivityItem(
                        id = '48c545831b264409a81befcabb0e3c5a', 
                        name = '48c545831b264409a81befcabb0e3c5a', 
                        requested = '2017-07-11T18:45:37.098Z', 
                        approval_status = 'PENDING', 
                        provisioning_status = 'PENDING', 
                        requester_comment = sailpoint.v2024.models.comment.Comment(
                            commenter_id = '2c918084660f45d6016617daa9210584', 
                            commenter_name = 'Adam Kennedy', 
                            body = 'Et quam massa maximus vivamus nisi ut urna tincidunt metus elementum erat.', 
                            date = '2017-07-11T18:45:37.098Z', ), 
                        reviewer_identity_summary = sailpoint.v2024.models.identity_summary.IdentitySummary(
                            id = 'ff80818155fe8c080155fe8d925b0316', 
                            name = 'SailPoint Services', 
                            identity_id = 'c15b9f5cca5a4e9599eaa0e64fa921bd', 
                            completed = True, ), 
                        reviewer_comment = sailpoint.v2024.models.comment.Comment(
                            commenter_id = '2c918084660f45d6016617daa9210584', 
                            commenter_name = 'Adam Kennedy', 
                            body = 'Et quam massa maximus vivamus nisi ut urna tincidunt metus elementum erat.', 
                            date = '2017-07-11T18:45:37.098Z', ), 
                        operation = 'ADD', 
                        attribute = 'detectedRoles', 
                        value = 'Treasury Analyst [AccessProfile-1529010191212]', 
                        native_identity = 'Sandie.Camero', 
                        source_id = '2c91808363ef85290164000587130c0c', 
                        account_request_info = sailpoint.v2024.models.account_request_info.AccountRequestInfo(
                            requested_object_id = '2c91808563ef85690164001c31140c0c', 
                            requested_object_name = 'Treasury Analyst', 
                            requested_object_type = 'ACCESS_PROFILE', ), 
                        client_metadata = {customKey1=custom value 1, customKey2=custom value 2}, 
                        remove_date = '2020-07-11T00:00Z', )
                    ],
                execution_status = 'COMPLETED',
                client_metadata = {customKey1=custom value 1, customKey2=custom value 2}
            )
        else:
            return AccountActivity(
        )
        """

    def testAccountActivity(self):
        """Test AccountActivity"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
