# coding: utf-8

"""
    Identity Security Cloud V2024 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2024
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v2024.api.access_request_identity_metrics_api import AccessRequestIdentityMetricsApi


class TestAccessRequestIdentityMetricsApi(unittest.TestCase):
    """AccessRequestIdentityMetricsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AccessRequestIdentityMetricsApi()

    def tearDown(self) -> None:
        pass

    def test_get_access_request_identity_metrics(self) -> None:
        """Test case for get_access_request_identity_metrics

        Return access request identity metrics
        """
        pass


if __name__ == '__main__':
    unittest.main()
