# coding: utf-8

"""
    Identity Security Cloud V2024 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2024
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from sailpoint.v2024.models.identity_reference_with_name_and_email import IdentityReferenceWithNameAndEmail
from sailpoint.v2024.models.reviewable_access_profile import ReviewableAccessProfile
from sailpoint.v2024.models.reviewable_entitlement import ReviewableEntitlement
from typing import Optional, Set
from typing_extensions import Self

class ReviewableRole(BaseModel):
    """
    ReviewableRole
    """ # noqa: E501
    id: Optional[StrictStr] = Field(default=None, description="The id for the Role")
    name: Optional[StrictStr] = Field(default=None, description="The name of the Role")
    description: Optional[StrictStr] = Field(default=None, description="Information about the Role")
    privileged: Optional[StrictBool] = Field(default=None, description="Indicates if the entitlement is a privileged entitlement")
    owner: Optional[IdentityReferenceWithNameAndEmail] = None
    revocable: Optional[StrictBool] = Field(default=None, description="Indicates whether the Role can be revoked or requested")
    end_date: Optional[datetime] = Field(default=None, description="The date when a user's access expires.", alias="endDate")
    access_profiles: Optional[List[ReviewableAccessProfile]] = Field(default=None, description="The list of Access Profiles associated with this Role", alias="accessProfiles")
    entitlements: Optional[List[Optional[ReviewableEntitlement]]] = Field(default=None, description="The list of entitlements associated with this Role")
    __properties: ClassVar[List[str]] = ["id", "name", "description", "privileged", "owner", "revocable", "endDate", "accessProfiles", "entitlements"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ReviewableRole from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of owner
        if self.owner:
            _dict['owner'] = self.owner.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in access_profiles (list)
        _items = []
        if self.access_profiles:
            for _item_access_profiles in self.access_profiles:
                if _item_access_profiles:
                    _items.append(_item_access_profiles.to_dict())
            _dict['accessProfiles'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in entitlements (list)
        _items = []
        if self.entitlements:
            for _item_entitlements in self.entitlements:
                if _item_entitlements:
                    _items.append(_item_entitlements.to_dict())
            _dict['entitlements'] = _items
        # set to None if owner (nullable) is None
        # and model_fields_set contains the field
        if self.owner is None and "owner" in self.model_fields_set:
            _dict['owner'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ReviewableRole from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "description": obj.get("description"),
            "privileged": obj.get("privileged"),
            "owner": IdentityReferenceWithNameAndEmail.from_dict(obj["owner"]) if obj.get("owner") is not None else None,
            "revocable": obj.get("revocable"),
            "endDate": obj.get("endDate"),
            "accessProfiles": [ReviewableAccessProfile.from_dict(_item) for _item in obj["accessProfiles"]] if obj.get("accessProfiles") is not None else None,
            "entitlements": [ReviewableEntitlement.from_dict(_item) for _item in obj["entitlements"]] if obj.get("entitlements") is not None else None
        })
        return _obj


