# coding: utf-8

"""
    Identity Security Cloud V2024 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2024
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v2024.models.campaign_all_of_role_composition_campaign_info_remediator_ref import CampaignAllOfRoleCompositionCampaignInfoRemediatorRef

class TestCampaignAllOfRoleCompositionCampaignInfoRemediatorRef(unittest.TestCase):
    """CampaignAllOfRoleCompositionCampaignInfoRemediatorRef unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CampaignAllOfRoleCompositionCampaignInfoRemediatorRef:
        """Test CampaignAllOfRoleCompositionCampaignInfoRemediatorRef
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CampaignAllOfRoleCompositionCampaignInfoRemediatorRef`
        """
        model = CampaignAllOfRoleCompositionCampaignInfoRemediatorRef()
        if include_optional:
            return CampaignAllOfRoleCompositionCampaignInfoRemediatorRef(
                type = 'IDENTITY',
                id = '2c90ad2a70ace7d50170acf22ca90010',
                name = 'Role Admin'
            )
        else:
            return CampaignAllOfRoleCompositionCampaignInfoRemediatorRef(
                type = 'IDENTITY',
                id = '2c90ad2a70ace7d50170acf22ca90010',
        )
        """

    def testCampaignAllOfRoleCompositionCampaignInfoRemediatorRef(self):
        """Test CampaignAllOfRoleCompositionCampaignInfoRemediatorRef"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
