# coding: utf-8

"""
    Identity Security Cloud V2024 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2024
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class EntitlementRequestConfig1(BaseModel):
    """
    EntitlementRequestConfig1
    """ # noqa: E501
    allow_entitlement_request: Optional[StrictBool] = Field(default=False, description="If this is true, entitlement requests are allowed.", alias="allowEntitlementRequest")
    request_comments_required: Optional[StrictBool] = Field(default=False, description="If this is true, comments are required to submit entitlement requests.", alias="requestCommentsRequired")
    denied_comments_required: Optional[StrictBool] = Field(default=False, description="If this is true, comments are required to reject entitlement requests.", alias="deniedCommentsRequired")
    grant_request_approval_schemes: Optional[StrictStr] = Field(default='sourceOwner', description="Approval schemes for granting entitlement request. This can be empty if no approval is needed. Multiple schemes must be comma-separated. The valid schemes are \"entitlementOwner\", \"sourceOwner\", \"manager\" and \"workgroup:{id}\". You can use multiple governance groups (workgroups). ", alias="grantRequestApprovalSchemes")
    __properties: ClassVar[List[str]] = ["allowEntitlementRequest", "requestCommentsRequired", "deniedCommentsRequired", "grantRequestApprovalSchemes"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of EntitlementRequestConfig1 from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if grant_request_approval_schemes (nullable) is None
        # and model_fields_set contains the field
        if self.grant_request_approval_schemes is None and "grant_request_approval_schemes" in self.model_fields_set:
            _dict['grantRequestApprovalSchemes'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of EntitlementRequestConfig1 from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "allowEntitlementRequest": obj.get("allowEntitlementRequest") if obj.get("allowEntitlementRequest") is not None else False,
            "requestCommentsRequired": obj.get("requestCommentsRequired") if obj.get("requestCommentsRequired") is not None else False,
            "deniedCommentsRequired": obj.get("deniedCommentsRequired") if obj.get("deniedCommentsRequired") is not None else False,
            "grantRequestApprovalSchemes": obj.get("grantRequestApprovalSchemes") if obj.get("grantRequestApprovalSchemes") is not None else 'sourceOwner'
        })
        return _obj


